@@ -7,7 +7,7 @@ use Term::TermKey qw( FLAG_UTF8 RES_EOF FORMAT_LONGMOD );
 my $tk = Term::TermKey->new(\*STDIN);
 
 # ensure perl and libtermkey agree on Unicode handling
-binmode( STDOUT, ":utf8" ) if $tk->get_flags & FLAG_UTF8;
+binmode( STDOUT, ":encoding(UTF-8)" ) if $tk->get_flags & FLAG_UTF8;
 
 my $line = "";
 
